@@ -2,21 +2,21 @@
 #ifndef _GLIBMM_MISCUTILS_H
 #define _GLIBMM_MISCUTILS_H
 
-/* $Id: miscutils.h,v 1.5 2006/09/10 14:38:53 jjongsma Exp $ */
+/* $Id$ */
 
 /* Copyright (C) 2002 The gtkmm Development Team
  *
  * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Library General Public
+ * modify it under the terms of the GNU Lesser General Public
  * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
+ * version 2.1 of the License, or (at your option) any later version.
  *
  * This library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Library General Public License for more details.
+ * Lesser General Public License for more details.
  *
- * You should have received a copy of the GNU Library General Public
+ * You should have received a copy of the GNU Lesser General Public
  * License along with this library; if not, write to the Free
  * Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
@@ -154,13 +154,31 @@ std::string get_tmp_dir();
  */
 std::string get_current_dir();
 
+//TODO: We could create a C++ enum to wrap the C GUserDirectory enum,
+//but we would have to either be very careful, or define the enum 
+//values in terms of the C enums anyway.
+/** Returns the full path of a special directory using its logical id.
+ *
+ * On Unix this is done using the XDG special user directories.
+ *
+ * Depending on the platform, the user might be able to change the path
+ * of the special directory without requiring the session to restart; GLib
+ * will not reflect any change once the special directories are loaded.
+ *
+ * Return value: the path to the specified special directory.
+ * @param directory Te logical id of special directory
+ * 
+ * @newin2p14
+ */
+std::string get_user_special_dir(GUserDirectory directory);
+
 /** Returns a base directory in which to access application data such as icons
  * that is customized for a particular user.
  *
  * On UNIX platforms this is determined using the mechanisms described in the
  * XDG Base Directory Specification
  *
- * @since glibmm 2.14
+ * @newin2p14
  */
 std::string get_user_data_dir();
 
@@ -170,7 +188,7 @@ std::string get_user_data_dir();
  * On UNIX platforms this is determined using the mechanisms described in the
  * XDG Base Directory Specification
  *
- * @since glibmm 2.14
+ * @newin2p14
  */
 std::string get_user_config_dir();
 
@@ -180,7 +198,7 @@ std::string get_user_config_dir();
  * On UNIX platforms this is determined using the mechanisms described in the
  * XDG Base Directory Specification
  *
- * @since glibmm 2.14
+ * @newin2p14
  */
 std::string get_user_cache_dir();
 
